<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="商品" prop="goodsId">
        <el-select v-model="queryParams.goodsId" filterable placeholder="请选择" style="width:100%">
          <el-option
            v-for="item in goodsList"
            :key="item.goodsId"
            :label="item.goodsTitle+'\t'+'\t'+item.className"
            :value="item.goodsId">
            <span style="float: left">{{ item.goodsTitle }}</span>
            <span style="float: right; color: #8492a6; font-size: 13px">{{ item.className }}</span>
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="秒杀时间" prop="timeId">
        <el-select v-model="queryParams.timeId" filterable placeholder="请选择" @change="changeEndTimeOptions($event)">
          <el-option
            v-for="(item,index) in seckillTimeList"
            :key="index"
            :label="item.timeHour+'-'+item.timeEnd"
            :value="item.id">
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['mall:mallSeckillGoods:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['mall:mallSeckillGoods:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['mall:mallSeckillGoods:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['mall:mallSeckillGoods:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="mallSeckillGoodsList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="id" align="center" prop="id" />-->
<!--      <el-table-column label="商品id" align="center" prop="goodsId" />-->
      <el-table-column label="商品名称" align="center" prop="goodsName" />
      <el-table-column label="商品标题" align="center" prop="goodsTitle" />
      <el-table-column label="商品logo" align="center" prop="goodsImg" >
        <template slot-scope="scope">
          <el-image :src="scope.row.goodsImg" style="width: 80px" :preview-src-list="[scope.row.goodsImg]"/>
        </template>
      </el-table-column>
      <el-table-column label="商品分类" align="center" prop="className" />
      <el-table-column label="秒杀价" align="center" prop="price" />
      <el-table-column label="库存" align="center" prop="stock" />
<!--      <el-table-column label="秒杀时间" align="center" prop="timeId" />-->
      <el-table-column label="秒杀时间" align="center" prop="seckillTime" />
      <el-table-column label="销量" align="center" prop="saleNum" />
      <el-table-column label="每人限购" align="center" prop="purchaseLimits" />
      <el-table-column label="状态" align="center" prop="status" >
        <template slot-scope="scope">
          <div v-if="scope.row.status == 0">显示</div>
          <div v-if="scope.row.status == 1">隐藏</div>
        </template>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createAt" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['mall:mallSeckillGoods:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['mall:mallSeckillGoods:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改秒杀商品对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="商品" prop="goodsId">
          <el-select v-model="form.goodsId" filterable placeholder="请选择" style="width:100%">
            <el-option
              v-for="item in goodsList"
              :key="item.goodsId"
              :label="item.goodsTitle+'\t'+'\t'+item.className"
              :value="item.goodsId">
              <span style="float: left">{{ item.goodsTitle }}</span>
              <span style="float: right; color: #8492a6; font-size: 13px">{{ item.className }}</span>
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="秒杀价" prop="price">
          <el-input v-model="form.price" placeholder="请输入秒杀价" />
        </el-form-item>
        <el-form-item label="库存" prop="stock">
          <el-input-number v-model="form.stock" controls-position="right" :min="0" placeholder="请输入库存" />
        </el-form-item>
        <el-form-item label="每人限购" prop="purchaseLimits">
          <el-input-number v-model="form.purchaseLimits" controls-position="right" :min="0" placeholder="请输入限购数量" />
        </el-form-item>
        <el-form-item label="秒杀时间" prop="timeId">
          <el-select v-model="form.timeId" filterable placeholder="请选择" @change="changeEndTimeOptions($event)">
            <el-option
              v-for="(item,index) in seckillTimeList"
              :key="index"
              :label="item.timeHour+'-'+item.timeEnd"
              :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="状态" prop="status">
          <template>
            <el-radio v-model="form.status" :label="0">显示</el-radio>
            <el-radio v-model="form.status" :label="1">隐藏</el-radio>
          </template>
        </el-form-item>
<!--        <el-form-item label="结束时间" prop="endTime">-->
<!--          <el-time-select-->
<!--            v-model="form.endTime"-->
<!--            :picker-options="endTimeOptions"-->
<!--            placeholder="选择时间">-->
<!--          </el-time-select>-->
<!--        </el-form-item>-->
        <el-form-item label="销量" prop="saleNum" v-if="this.form.id != null">
          <el-input v-model="form.saleNum" placeholder="请输入销量" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { enableSeckillGoodsList, listMallSeckillGoods, getMallSeckillGoods, delMallSeckillGoods, addMallSeckillGoods, updateMallSeckillGoods, exportMallSeckillGoods } from "@/api/mall/mallSeckillGoods";
import { seckillTimeSelectList } from "@/api/mall/mallSeckillTime";

export default {
  name: "MallSeckillGoods",
  data() {
    return {
      endTimeOptions:{
        start: '00:00',
        step: '01:00',
        end: '24:00'
      },
      seckillTimeList:[],
      goodsList:[],
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 秒杀商品表格数据
      mallSeckillGoodsList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        id: null,
        goodsId: null,
        price: null,
        stock: null,
        timeId: null,
        endTime: null,
        saleNum: null,
        status: null,
        createAt: null,
        delFlag: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        goodsId: [
          { required: true, message: "商品不能为空", trigger: "blur" }
        ],
        timeId: [
          { required: true, message: "开始时间不能为空", trigger: "blur" }
        ],
        price: [
          { required: true, message: "价格不能为空", trigger: "blur" }
        ],
        stock: [
          { required: true, message: "库存不能为空", trigger: "blur" }
        ],
        purchaseLimits: [
          { required: true, message: "限购数量不能为空", trigger: "blur" }
        ],
        endTime: [
          { required: true, message: "结束时间不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
    enableSeckillGoodsList().then(res =>{
      this.goodsList = res.data
    });
    seckillTimeSelectList().then(res =>{
      this.seckillTimeList = res.data
    });
  },
  methods: {
    changeEndTimeOptions(e){
      var obj = {}
      obj = this.seckillTimeList.find(function(item){
        return item.id == e
      })
      this.endTimeOptions.start = obj.timeHour
    },
    /** 查询秒杀商品列表 */
    getList() {
      this.loading = true;
      listMallSeckillGoods(this.queryParams).then(response => {
        this.mallSeckillGoodsList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        goodsId: null,
        price: null,
        stock: null,
        timeId: null,
        endTime: null,
        saleNum: null,
        createAt: null,
        delFlag: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加秒杀商品";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getMallSeckillGoods(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改秒杀商品";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateMallSeckillGoods(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addMallSeckillGoods(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除秒杀商品编号为"' + ids + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delMallSeckillGoods(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有秒杀商品数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportMallSeckillGoods(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    }
  }
};
</script>
